DeltaTextView class

Inheritance

Constructors

DeltaTextView({Key? key, required Delta delta, required MentionConfig? mentionConfig, required TextStyle defaultStyle, EmojiConfig? emojiConfig = const EmojiConfig(), double? emojiOnlySize = 48, int? maxLines, TextAlign textAlign = TextAlign.start, Color? selectionColor, bool? selectable, void onSelectionChangedAsDelta(Delta? selectionDelta)?, GestureTapCallback? onTapSelectableText, TextOverflow? overflow, Widget contextMenuBuilder(BuildContext, EditableTextState)?, dynamic onLinkTap = _kDefaultLinkTap})
const

Properties

contextMenuBuilder Widget Function(BuildContext, EditableTextState)?
Переопределяет контекстное меню для SelectableText. Передайте (_, __) => const SizedBox.shrink() чтобы отключить системное меню.
final
defaultStyle TextStyle
final
delta Delta
final
emojiConfig EmojiConfig?
Конфигурация для разбора и отображения emoji-эмбедов.
final
emojiOnlySize double?
Размер emoji когда дельта содержит только emoji-эмбеды.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLines int?
final
mentionConfig MentionConfig?
Конфигурация для разбора и отображения упоминаний произвольного типа.
final
onLinkTap → void Function(String url)?
no setter
onSelectionChangedAsDelta → void Function(Delta? selectionDelta)?
final
onTapSelectableText GestureTapCallback?
Callback при нажатии на область с выделяемым текстом (SelectableText).
final
overflow TextOverflow?
Поведение при переполнении. Можно использовать только когда selectable = null.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectable bool?
Разрешить выделение текста пользователем.
final
selectionColor Color?
final
textAlign TextAlign
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DeltaTextView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited