Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
deltaWithEmojisAsText(Delta delta, {EmojiConfig? emojiConfig})
→ Delta
-
Конвертирует emoji-эмбеды в plain text (сам символ emoji).
-
deltaWithMentionsAsText(Delta delta, {MentionConfig? mentionConfig})
→ Delta
-
-
exceedsMaxLines({required Delta delta, required TextStyle baseStyle, required double maxWidth, required int maxLines, MentionConfig? mentionConfig, EmojiConfig? emojiConfig, TextDirection textDirection = TextDirection.ltr, TextScaler textScaler = TextScaler.noScaling})
→ bool
-
Проверяет, не помещается ли
delta в maxLines визуальных строк
при ширине maxWidth и стиле baseStyle.
-
parseDeltaToSpans({MentionConfig? mentionConfig, EmojiConfig? emojiConfig, required Delta delta, TextStyle? baseStyle, void onMentionSelectedAsDelta(Delta)?, bool applyBlockPrefixes = false, TextSelection? selectionRange, Color? selectionColor, void onLinkTap(String url)?})
→ List<InlineSpan>
-